@@ -3,7 +3,8 @@ import os
 
 import urlparse
 
-from urllib2 import urlopen, URLError, quote
+from urllib import quote # for Python 2.4 compatibility
+from urllib2 import urlopen, URLError
 from pkg_resources import resource_filename
 
 from tiddlyweb.util import write_utf8_file, std_error_message
